@@ -39,6 +39,13 @@ asui_download()
 		chmod 755 /root/.advanced-systemui-$1
 	fi
 }
+stop_systemui()
+{
+	if pidof systemui > /dev/null; then
+		echo "SystemUI is running - stopping it..."
+		/etc/init.d/osso-systemui stop || exit $?
+	fi
+}
 case $1 in
 	show)
 		run-standalone.sh /usr/bin/dbus-send --system --type=method_call --dest=com.qzx.asui /com/qzx/asui com.qzx.asui.show
@@ -67,6 +74,7 @@ case $1 in
 		;;
 	rt)
 		if [ -e /root/.advanced-systemui-test ]; then
+			stop_systemui
 			run-standalone.sh /root/.advanced-systemui-test
 		else
 			echo "You must first run 'asui dt' to download the test binary"
@@ -92,6 +100,7 @@ case $1 in
 		;;
 	rd)
 		if [ -e /root/.advanced-systemui-debug ]; then
+			stop_systemui
 			run-standalone.sh /root/.advanced-systemui-debug
 		else
 			echo "You must first run 'asui dd' to download the debug binary"
