@@ -16,6 +16,7 @@
 const char *conf_max_brightness = "/system/osso/dsm/display/max_display_brightness_levels";
 const char *conf_brightness = "/system/osso/dsm/display/display_brightness";
 const char *conf_dim_timeout = "/system/osso/dsm/display/display_dim_timeout";
+const char *conf_blank_timeout = "/system/osso/dsm/display/display_blank_timeout";
 const char *conf_volume = "/apps/osso/sound/master_volume";
 const char *conf_screen_autolock1 = "/apps/osso/applet/osso-applet-display/lock_screen";
 const char *conf_screen_autolock2 = "/system/osso/dsm/locks/touchscreen_keypad_autolock_enabled";
@@ -32,7 +33,7 @@ GConfClient *gconf_client;
 unsigned cfg_battery_idle_time, cfg_memory_format, cfg_swap_format, cfg_temperature_F;
 // clock
 unsigned cfg_clock_24h, cfg_clock_ampm;
-unsigned cfg_popup_duration, cfg_popup_onmap, cfg_popup_fullscreen;
+unsigned cfg_popup_duration, cfg_popup_onmap, cfg_popup_fullscreen, cfg_popup_cooldown, cfg_popup_noasui;
 // brightness
 unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
 // BRV keys
@@ -98,6 +99,8 @@ static const char *conf_clock_ampm = "/apps/asui/clock_ampm";
 static const char *conf_popup_duration = "/apps/asui/popup_duration";
 static const char *conf_popup_onmap = "/apps/asui/popup_onmap";
 static const char *conf_popup_fullscreen = "/apps/asui/popup_fullscreen";
+static const char *conf_popup_cooldown = "/apps/asui/popup_cooldown";
+static const char *conf_popup_noasui = "/apps/asui/popup_noasui";
 // brightness
 static const char *conf_brightness_enhanced = "/apps/asui/brightness_enhanced";
 static const char *conf_brightness_allow_zero = "/apps/asui/brightness_allow_zero";
@@ -310,6 +313,8 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_popup_duration, NULL);
 	gconf_client_unset(gconf_client, conf_popup_onmap, NULL);
 	gconf_client_unset(gconf_client, conf_popup_fullscreen, NULL);
+	gconf_client_unset(gconf_client, conf_popup_cooldown, NULL);
+	gconf_client_unset(gconf_client, conf_popup_noasui, NULL);
 	// brightness
 	gconf_client_unset(gconf_client, conf_brightness_enhanced, NULL);
 	gconf_client_unset(gconf_client, conf_brightness_allow_zero, NULL);
@@ -418,6 +423,8 @@ void config_reload( ){
 	make_uint(&cfg_popup_duration,			conf_popup_duration,			0,		0);					// default: 0	popup diabled
 	make_bool(&cfg_popup_onmap,				conf_popup_onmap,				0,		0);					// default: 0	off
 	make_bool(&cfg_popup_fullscreen,		conf_popup_fullscreen,			0,		0);					// default: 0	small popup window
+	make_uint(&cfg_popup_cooldown,			conf_popup_cooldown,			300,	0);					// default: 300	5 minutes
+	make_bool(&cfg_popup_noasui,			conf_popup_noasui,				1,		0);					// default: 1	don't show while ASUI mapped
 	// brightness
 	make_bool(&cfg_brightness_enhanced,		conf_brightness_enhanced,		!is_770,HW_BRIGHTNESS);		// default: 1	all 127 brightness levels
 	make_bool(&cfg_brightness_allow_zero,	conf_brightness_allow_zero,		0,		HW_BRIGHTNESS);		// default: 0	don't allow zero brightness
@@ -461,6 +468,7 @@ void config_reload( ){
 
 	// popup window duration
 	if(cfg_popup_duration > 15){ cfg_popup_duration = 5; conf_set_int(conf_popup_duration, 5); }
+	if(cfg_popup_cooldown < 60 || cfg_popup_cooldown > 3600){ cfg_popup_cooldown = 300; conf_set_int(conf_popup_cooldown, 300); }
 
 	// make sure buttons are correctly bound and don't exceed step values
 	if(cfg_buttons_rotate > 3){ cfg_buttons_rotate = 0; conf_set_int(conf_buttons_rotate, 0); } // disable if invalid
@@ -568,6 +576,8 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_popup_duration = %u", cfg_popup_duration);
 	debug_write("  cfg_popup_onmap = %u", cfg_popup_onmap);
 	debug_write("  cfg_popup_fullscreen = %u", cfg_popup_fullscreen);
+	debug_write("  cfg_popup_cooldown = %u", cfg_popup_cooldown);
+	debug_write("  cfg_popup_noasui = %u", cfg_popup_noasui);
 	// brightness
 	debug_write("  cfg_brightness_enhanced = %u", cfg_brightness_enhanced);
 	debug_write("  cfg_brightness_allow_zero = %u", cfg_brightness_allow_zero);
