@@ -51,6 +51,8 @@ static const char *_notification_interface_ = "org.freedesktop.Notifications";
 static const char *_notification_method_ = "SystemNoteInfoprint"; // method
 #endif
 
+static unsigned acting_dead_state;
+
 //////////////////////////////////////////////////////////////////////////
 
 #ifdef ARCH_armel
@@ -137,12 +139,94 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 		}
 		return DBUS_HANDLER_RESULT_HANDLED;
 
-//	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "devlock_open")){
-//
-//		printf("[DBUS] method: com.nokia.system_ui.request.devlock_open\n");
-//
-//		return DBUS_HANDLER_RESULT_HANDLED;
+	////////////////////
+	// DEVLOCK UI
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "devlock_open")){
 
+		debug_write("[DBUS] method: com.nokia.system_ui.request.devlock_open");
+
+		int response = 1;
+		dbus_send_reply(signal_bus, message, _INT32_, &response, _END_);
+		// reply to this so MCE will change state to locked and send out signal
+
+		if(hw_screen.locked)
+			mce_lock_screen(0);
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+    } else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "devlock_close")){
+
+		debug_write("[DBUS] method: com.nokia.system_ui.request.devlock_close");
+
+		// don't need to do anything
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+	////////////////////
+	// ALARM UI
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "alarm_open")){
+		char *cd_service, *cb_path, *cb_iface, *cb_method, *description, *sound, *image, *title;
+		unsigned mode, timestamp;
+
+		debug_write("[DBUS] method: com.nokia.system_ui.request.alarm_open");
+
+		if(dbus_message_get_args(message, &dbus_error, _STRING_, &cd_service, _STRING_, &cb_path, _STRING_, &cb_iface, _STRING_, &cb_method,
+		   _UINT32_, &mode, _STRING_, &description, _STRING_, &sound, _STRING_, &image, _STRING_, &title, _UINT32_, &timestamp, _END_))
+		{
+
+const char *modes[] = {"normal", "no snooze", "switch on"};
+printf("ALARM: [%s] \"%s\"\n       [PLAY] %s\n", modes[mode], description, sound);
+//foo
+
+int response = GTK_RESPONSE_ACCEPT;
+dbus_send_reply(signal_bus, message, _INT32_, &response, _END_); // or GTK_RESPONSE_REJECT
+
+
+// dismiss the alarm
+unsigned status = 2; // 1:snooze, 2:dismiss, 3:powerUP, 4:powerDOWN
+dbus_send_method(cd_service, cb_path, cb_iface, cb_method, _INT32_, &status, _END_);
+
+			return DBUS_HANDLER_RESULT_HANDLED;
+		}
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "alarm_close")){
+
+// remove \n
+printf("[DBUS] method: com.nokia.system_ui.request.alarm_close\n");
+
+// TODO: close the alarm popup
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "acting_dead_open")){
+
+// remove \n
+printf("[DBUS] method: com.nokia.system_ui.request.acting_dead_open\n");
+
+// TODO: inputs? reply value?
+acting_dead_state = 1;
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "acting_dead_close")){
+
+// remove \n
+printf("[DBUS] method: com.nokia.system_ui.request.acting_dead_close\n");
+acting_dead_state = 0;
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "acring_dead_getstate")){
+
+// remove \n
+printf("[DBUS] method: com.nokia.system_ui.request.acring_dead_getstate\n");
+
+		dbus_send_reply(signal_bus, message, _BOOL_, &acting_dead_state, _END_);
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
+	////////////////////
+	// HAL
 	} else if(dbus_message_is_signal(message, "org.freedesktop.Hal.Device", "Condition")){
 		char *s1, *s2;
 
@@ -184,7 +268,7 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 						if(!window.is_mapped) window_open_blank(); // open blank to catch keys
 						notify_power_unlock_key();
 					} else {
-						if(hw_screen.locked) mce_lock_screen();
+						if(hw_screen.locked) mce_lock_screen(0);
 						window_close_blank();
 					}
 					hw_query_headphones();
@@ -406,7 +490,7 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 		if(hw_screen.locked){
 			// lock&blank doesn't properly lock the screen and connecting charger will unlock it
 			// without sending an unlock signal
-			mce_lock_screen();
+			mce_lock_screen(0);
 		}
 
 		if(hw_battery.status == BATTERY_DRAINING){
@@ -667,7 +751,7 @@ static void *dbus_thread( void *arg ){
 
 		// listen for flush signals from self
 		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/qzx/asui',interface='com.qzx.asui'", &dbus_error);
-//		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request'", &dbus_error);
+		dbus_bus_add_match(signal_bus, "type='method_call',path='/com/nokia/system_ui/request',interface='com.nokia.system_ui.request'", &dbus_error);
 
 		// power button signal
 		dbus_bus_add_match(signal_bus, "type='signal',path='/org/freedesktop/Hal/devices/computer_logicaldev_input_0',"	// n810
@@ -748,10 +832,10 @@ int dbus_init( ){
 		error_write("dbus won't let me register as com.qzx.asui: %s", dbus_error.message);
 		dbus_error_free(&dbus_error);
 	}
-//	if(dbus_bus_request_name(signal_bus, "com.nokia.system_ui", DBUS_NAME_FLAG_REPLACE_EXISTING, &dbus_error) == -1){
-//		error_write("dbus won't let me register as com.nokia.system_ui: %s", dbus_error.message);
-//		dbus_error_free(&dbus_error);
-//	}
+	if(dbus_bus_request_name(signal_bus, "com.nokia.system_ui", DBUS_NAME_FLAG_REPLACE_EXISTING, &dbus_error) == -1){
+		error_write("dbus won't let me register as com.nokia.system_ui: %s", dbus_error.message);
+		dbus_error_free(&dbus_error);
+	}
 	#endif
 
 	if(pipe(threadpipe) < 0){
@@ -794,6 +878,21 @@ void dbus_send_method( const char *destination, const char *path, const char *in
 	dbus_message_unref(message);
 }
 
+void dbus_send_reply( DBusConnection *bus, DBusMessage *method_call, int first_arg_type, ... ){
+	DBusMessage *message;
+	va_list ap;
+
+	message = dbus_message_new_method_return(method_call);
+	if(first_arg_type != _END_){
+		va_start(ap, first_arg_type);
+		dbus_message_append_args_valist(message, first_arg_type, ap);
+		va_end(ap);
+	}
+	if(dbus_connection_send(bus, message, NULL) != FALSE)
+		dbus_connection_flush(bus);
+	dbus_message_unref(message);
+}
+
 void dbus_send_signal( const char *path, const char *interface, const char *signal, int first_arg_type, ... ){
 	DBusMessage *message;
 	va_list ap;
@@ -885,7 +984,8 @@ void notify_power_unlock_key( ){
 	if(cfg_power_unlock_key){
 		dbus_send_session_method(_notification_service_, _notification_path_, _notification_interface_, _notification_method_,
 									_STRING_, &power_unlock_messages[cfg_power_unlock_key], _END_);
-		mce_dim_screen();
+		if(conf_get_screen_blank_offset() > 10)
+			mce_dim_screen();
 	}
 	#endif
 }
@@ -898,8 +998,8 @@ void notify_blanking_pause1( ){
 }
 void notify_blanking_pause2( ){
 	#ifdef ARCH_armel
-	char *locked_message   = "Screen is LOCKED and should dim in less than 60 seconds";
-	char *unlocked_message = "Screen is UNLOCKED and should dim in less than 60 seconds";
+	const char *locked_message   = "Screen is LOCKED and should dim in a minute...";
+	const char *unlocked_message = "Screen is UNLOCKED and should dim in a minute...";
 	dbus_send_session_method(_notification_service_, _notification_path_, _notification_interface_, _notification_method_,
 								_STRING_, (hw_screen.locked ? &locked_message : &unlocked_message), _END_);
 	#endif
