@@ -1,5 +1,30 @@
 #include <dbus/dbus.h>
 
+typedef enum {
+  // GTK returns this if a response widget has no response_id,
+  // or if the dialog gets programmatically hidden or destroyed.
+  GTK_RESPONSE_NONE = -1,
+
+  // GTK won't return these unless you pass them in
+  // as the response for an action widget. They are
+  // for your convenience.
+  GTK_RESPONSE_REJECT = -2,
+  GTK_RESPONSE_ACCEPT = -3,
+
+  // If the dialog is deleted.
+  GTK_RESPONSE_DELETE_EVENT = -4,
+
+  // These are returned from GTK dialogs, and you can also use them
+  // yourself if you like.
+  GTK_RESPONSE_OK     = -5,
+  GTK_RESPONSE_CANCEL = -6,
+  GTK_RESPONSE_CLOSE  = -7,
+  GTK_RESPONSE_YES    = -8,
+  GTK_RESPONSE_NO     = -9,
+  GTK_RESPONSE_APPLY  = -10,
+  GTK_RESPONSE_HELP   = -11
+} GtkResponseType;
+
 #define _STRING_ DBUS_TYPE_STRING
 #define _BOOL_ DBUS_TYPE_BOOLEAN
 #define _UINT32_ DBUS_TYPE_UINT32
@@ -36,6 +61,7 @@ int dbus_init( );
 void dbus_disconnect( );
 
 void dbus_send_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
+void dbus_send_reply( DBusConnection *bus, DBusMessage *method_call, int first_arg_type, ... );
 void dbus_send_signal( const char *path, const char *interface, const char *signal, int first_arg_type, ... );
 
 void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
