@@ -14,6 +14,7 @@
 #include <hildon/hildon.h>
 #include <dirent.h>
 #include <gconf/gconf-client.h>
+#include <assert.h>
 
 #define _STRING_ DBUS_TYPE_STRING
 #define _BOOL_ DBUS_TYPE_BOOLEAN
@@ -66,6 +67,8 @@ static const char *conf_clock_ampm = "/apps/asui/clock_ampm";
 static const char *conf_popup_duration = "/apps/asui/popup_duration";
 static const char *conf_popup_onmap = "/apps/asui/popup_onmap";
 static const char *conf_popup_fullscreen = "/apps/asui/popup_fullscreen";
+static const char *conf_popup_cooldown = "/apps/asui/popup_cooldown";
+static const char *conf_popup_noasui = "/apps/asui/popup_noasui";
 // brightness
 static const char *conf_brightness_enhanced = "/apps/asui/brightness_enhanced";
 static const char *conf_brightness_allow_zero = "/apps/asui/brightness_allow_zero";
@@ -225,13 +228,14 @@ void default_uint_value_callback( GObject *gobject, GParamSpec *arg1, gpointer u
 	g_object_get(gobject, "value", &value, NULL);
 	if(value >= 0) conf_set_int((const char *)user_data, value);
 }
-GtkWidget *new_uint_value( const char *conf, char *name, unsigned max_value, void (*callback)(GObject *gobject, GParamSpec *arg1, gpointer user_data) ){
+GtkWidget *new_uint_value( const char *conf, char *name, unsigned min_value, unsigned max_value, void (*callback)(GObject *gobject, GParamSpec *arg1, gpointer user_data) ){
+	assert(min_value == 0 || callback != NULL); // default callback can't be used if min_value > 0
 	// hbox
 	GtkWidget *hbox = gtk_hbox_new(FALSE, 10);
 	gtk_box_pack_start(GTK_BOX(section_content_box), hbox, FALSE, FALSE, 10);
 	gtk_widget_show(hbox);
 	// numeric entry with arrows
-	GtkWidget *editor = hildon_number_editor_new(0, max_value);
+	GtkWidget *editor = hildon_number_editor_new(min_value, max_value);
 	hildon_number_editor_set_value((HildonNumberEditor *)editor, conf_get_int(conf));
 	gtk_signal_connect(GTK_OBJECT(editor), "notify", GTK_SIGNAL_FUNC(callback == NULL ? default_uint_value_callback : callback), (void *)conf);
 	gtk_box_pack_start(GTK_BOX(hbox), editor, FALSE, FALSE, 20);
