@@ -20,8 +20,8 @@ void ui_click_callback( GtkWidget *widget, gpointer data ){
 	new_separator();
 
 	new_message("When ALS value exceeds the white threshold the white theme is activated and returns to black theme when value drops below the black threshold.");
-	new_uint_value(conf_threshold_black, "black threshold [n810 only]", 999999999, NULL);
-	new_uint_value(conf_threshold_white, "white threshold [n810 only]", 999999999, NULL);
+	new_uint_value(conf_threshold_black, "black threshold [n810 only]", 0, 999999999, NULL);
+	new_uint_value(conf_threshold_white, "white threshold [n810 only]", 0, 999999999, NULL);
 
 	new_separator();
 }
