@@ -107,6 +107,7 @@ void brightness_init( ){
 	// make sure stored brightness matches current brightness
 	// this doesn't work when turning off enhanced brightness
 	hw_set_brightness(hw_screen.brightness_level, 1);
+	hw_screen.brightness_mismatch = 1;
 	#else
 	hw_screen.brightness_max = 100;
 	hw_screen.brightness_level = 50;
@@ -437,13 +438,13 @@ void mce_lock_and_blank_screen( ){
 	#endif
 }
 
-void mce_lock_screen( ){
+void mce_lock_screen( unsigned expect ){
 	#ifdef ARCH_armel
 	// lock screen, dims and turns off after a minute
 	if(hw_battery.status == BATTERY_DRAINING || !conf_get_screen_stayslit_value())
 		dsme_allow_blanking(); // make sure screen isn't paused
 	dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, _mce_req_tklock_mode_change_, _STRING_, &_mce_tklock_LOCKED_, _END_);
-	if(hw_battery.status == BATTERY_DRAINING || !conf_get_screen_stayslit_value())
+	if(expect && (hw_battery.status == BATTERY_DRAINING || !conf_get_screen_stayslit_value()))
 		dsme_expect_display_state(DSME_DISPLAY_DIM);
 	#endif
 }
@@ -525,8 +526,6 @@ void mce_flight_mode( ){
 	// enable flight mode
 	dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, _mce_req_device_mode_change_, _STRING_, &_mce_device_FLIGHT_, _END_);
 
-	debug_write("*** ENTER FLIGHT MODE ***");
-
 	usleep(100000); // 100ms sleep to let MCE process method
 	hw_query_flight_mode(1);
 	#endif
@@ -539,14 +538,10 @@ void mce_lock_device( ){
 	if(!hw_device_locked){
 		int lock = 3;
 		dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, _mce_devlock_callback_, _INT32_, &lock, _END_);
+		// MCE will call ASUI's com.nokia.system_ui.request.devlock_open method and then send out a lock signal which puts ASUI in secure mode
 
-// TODO: the above call does absolutely nothing without systemui running
-//		MCE's internal lock state remains unlocked and restarting ASUI or rebooting system will result in an unlocked device
-//		if locked and then systemui starts, MCE will update its internal state
+// TODO: ASUI should call this method each time an incorrect code is entered so MCE can update gconf values for failures
 
-		// MCE doesn't send out a locked signal so send we need to send it for anything listening
-		dbus_send_signal("/com/nokia/mce/signal", "com.nokia.mce.signal", "devicelock_mode_ind", _STRING_, &_mce_device_LOCKED_, _END_);
-		// dbus thread will see this signal and put ASUI into secure mode
 	}
 	#endif
 }
@@ -598,7 +593,7 @@ static void bme_get_capacity_callback( DBusPendingCall *pending, void *user_data
 	debug_write("[DBUS] callback: bme_get_capacity_callback");
 	if(dbus_message_get_args(message, &dbus_error, _INT32_, &current, _END_)){
 		float capacity = round(1000.0 * current / battery_reporting_design) / 10;
-		if(capacity > 100) capacity = 100.0;
+		if(capacity > 100.0) capacity = 100.0;
 		if(hw_battery.capacity != capacity){ hw_battery.capacity = capacity; hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 		hw_initialized &= ~HWIS_BME_CAPACITY;
 		dbus_send_battery_capacity_signal();
@@ -1477,3 +1472,12 @@ void hw_refresh( ){
 
 	last_hw_refresh = current_time;
 }
+
+void hw_refresh_popup( ){
+	// grab this first so the other queries don't cause ondemand governor to increase cpu speed and scew the result
+	hw_query_cpu(0);
+
+	hw_query_memory();
+	hw_query_temperature();
+	hw_query_als();
+}
