@@ -977,7 +977,7 @@ void press_lock_button( unsigned action ){
 		break;
 	case 1: // lock
 		if(cfg_lock_and_close && !hw_device_autolocked) window_unmap();
-		mce_lock_screen();
+		mce_lock_screen(1);
 		break;
 	case 2: // lock&blank
 		if(cfg_lock_and_close && !hw_device_autolocked) window_unmap();
@@ -1155,6 +1155,24 @@ unsigned ready_to_read( int fd ){
 	return 0;
 }
 
+void detect_runlevel_transition( ){
+	// detect runlevel transition (5 -> 2)
+	FILE *in = popen("runlevel", "r");
+	if(in){
+		int runlevel = 0;
+		fscanf(in, "5 %d", &runlevel);
+		pclose(in);
+		if(runlevel == 2){
+			debug_write("leaving charging runlevel (boot)");
+			config_reload();
+			use_minimal_ui = 0;
+			#ifdef DEBUG
+			debug_runlevel = runlevel;
+			#endif
+		}
+	}
+}
+
 int main( int argc, char *argv[] ){
 	// detect runlevel
 	int runlevel = 0;
@@ -1206,20 +1224,20 @@ int main( int argc, char *argv[] ){
 	signal(SIGSEGV, segfault_handler);
 
 /*
-	if(runlevel == 2){
-		// sleep until system has fully booted
-		int idle_boot = 0;
-		while(!idle_boot){
-			FILE *in;
-			if((in = fopen("/proc/uptime", "r")) != NULL){
-				float uptime, idle;
-				fscanf(in, "%f %f", &uptime, &idle);
-				fclose(in);
-				if(idle > 2.0) idle_boot = 1;
-			}
-			if(!idle_boot) sleep(2);
+if(runlevel == 2){
+	// sleep until system has fully booted
+	int idle_boot = 0;
+	while(!idle_boot){
+		FILE *in;
+		if((in = fopen("/proc/uptime", "r")) != NULL){
+			float uptime, idle;
+			fscanf(in, "%f %f", &uptime, &idle);
+			fclose(in);
+			if(idle > 2.0) idle_boot = 1;
 		}
+		if(!idle_boot) sleep(2);
 	}
+}
 */
 
 	// time at which service was started, excluding the above sleep state
@@ -1302,6 +1320,8 @@ int main( int argc, char *argv[] ){
 	widget_edit_mode = 0;
 	if(cfg_start_visible) window_map();
 
+	dbus_send_signal("/com/nokia/system_ui/signal", "com.nokia.system_ui.signal", "system_ui_started", _END_);
+
 	////////////////////
 
 	int x_fd = ConnectionNumber(window.display);
@@ -1799,17 +1819,7 @@ int main( int argc, char *argv[] ){
 					// refresh service and hardware values
 					if(main_refresh_all){
 						if(use_minimal_ui){
-							// detect runlevel transition (5 -> 2)
-							FILE *in = popen("runlevel", "r");
-							if(in){
-								int runlevel = 0;
-								fscanf(in, "5 %d", &runlevel);
-								pclose(in);
-								if(runlevel == 2){
-									debug_write("leaving charging runlevel (boot)");
-									goto exit; // terminate and let DSME restart it with full interface
-								}
-							}
+							detect_runlevel_transition();
 
 //							// continuously poll battery capacity once fully charged in case the signals don't work properly
 //							if(hw_battery.status == BATTERY_AC)
