@@ -26,7 +26,7 @@ unsigned svc_bluetooth_status, svc_gps_status, svc_wifi_status, svc_audio_status
 unsigned svc_bluetooth_size, svc_gps_size, svc_wifi_size, svc_audio_size, svc_desktop_size, svc_ssh_size, svc_vpn_size, svc_self_size;
 
 unsigned svc_bluetooth_HCI, svc_bluetooth_BTCOND, svc_bluetooth_OBEX;
-unsigned svc_gps_DRIVER, svc_gps_SUPL, svc_gps_CLOCKD;
+unsigned svc_gps_DRIVER, svc_gps_SUPL, svc_gps_CLOCKD, svc_gps_GUARD;
 unsigned svc_wifi_WLANCOND, svc_wifi_DNSMASQ, svc_wifi_CONNDLGS, svc_wifi_ICD, svc_wifi_NTPD;
 unsigned svc_audio_MULTIMEDIA, svc_audio_DSP, svc_audio_ENGINE, svc_audio_ESD, svc_audio_SERVER;
 
@@ -118,7 +118,7 @@ void svc_refresh( ){
 	unsigned tmp_status;
 
 	svc_bluetooth_HCI = svc_bluetooth_BTCOND = svc_bluetooth_OBEX = 0;
-	svc_gps_DRIVER = svc_gps_SUPL = svc_gps_CLOCKD = 0;
+	svc_gps_DRIVER = svc_gps_SUPL = svc_gps_CLOCKD = svc_gps_GUARD = 0;
 	svc_wifi_WLANCOND = svc_wifi_DNSMASQ = svc_wifi_CONNDLGS = svc_wifi_ICD = svc_wifi_NTPD = 0;
 	svc_audio_MULTIMEDIA = svc_audio_DSP = svc_audio_ENGINE = svc_audio_ESD = svc_audio_SERVER = 0;
 
@@ -133,6 +133,7 @@ void svc_refresh( ){
 		{"/usr/sbin/gpsdriver", &svc_gps_DRIVER, &sc_gps_size},
 		{"/usr/sbin/supllistenerd", &svc_gps_SUPL, &sc_gps_size}, // optional
 		{"/usr/sbin/gps-clockd", &svc_gps_CLOCKD, &sc_gps_size}, // optional
+		{"(gpsdriver_guard)", &svc_gps_GUARD, &sc_gps_size}, // optional (/bin/sh /usr/local/sbin/gpsdriver_guard)
 		// WIFI
 		{"/usr/sbin/wlancond", &svc_wifi_WLANCOND, &sc_wifi_size},
 		{"/usr/sbin/dnsmasq", &svc_wifi_DNSMASQ, &sc_wifi_size},
@@ -168,6 +169,10 @@ void svc_refresh( ){
 		{"/usr/lib/sapwood/sapwood-server",		0},
 		{"/usr/bin/hildon-input-method",		0},
 		{"/usr/bin/clipboard-manager",			0},
+		// services
+		{"/usr/bin/alarmd",					0},
+		{"/usr/sbin/browserd",				0},
+		{"/usr/bin/metalayer-crawler",		0},
 		// system
 		{"/usr/libexec/gnome-vfs-daemon",	0},
 		{"/usr/lib/gconf2/gconfd-2",		0},
@@ -234,7 +239,7 @@ void svc_refresh( ){
 		while((file = readdir(proc))){
 			if(file->d_name[0] > '0' && file->d_name[0] <= '9'){
 				char filepath[30], command[PATH_MAX], cmdline[400], state;
-				unsigned ticks = 0, rss = 0, is_service = 0;
+				unsigned ticks = 0, rss = 0, is_service = 0, is_shell = 0;
 				FILE *p;
 
 				// state, resident set size and cpu%
@@ -254,6 +259,7 @@ void svc_refresh( ){
 					if((p = fopen(filepath, "r")) != NULL){
 						fgets(cmdline, sizeof(cmdline), p);
 						fclose(p);
+						if(!strcmp(cmdline, "/bin/sh")) is_shell = 1;
 					} else cmdline[0] = '\0';
 				} else cmdline[0] = '\0';
 
@@ -262,7 +268,14 @@ void svc_refresh( ){
 					int i;
 					for(i = 0; services[i].name != NULL; i++){
 						s_service *s = &services[i];
-						if(!strcmp(cmdline, s->name)){
+						if(is_shell){
+							if(!strcmp(command, s->name)){
+								if(s->running) *s->running = 1;
+								*s->rss += rss;
+								is_service = 1;
+								break;
+							}
+						} else if(!strcmp(cmdline, s->name)){
 							if(s->running){
 								if(s->running == &sc_dropbear) sc_dropbear++; else *s->running = 1;
 							}
@@ -289,7 +302,7 @@ void svc_refresh( ){
 					sscanf(file->d_name, "%u", &pid);
 
 					// strip path from process name
-					if(cmdline[0] != '\0'){
+					if(cmdline[0] != '\0' && !is_shell){
 						for(end = 0; cmdline[end] != '\0' && cmdline[end] != ' '; end++);
 						for(start = end; cmdline[start] != '/' && start > 0; start--);
 						if(cmdline[start] == '/') start++;
@@ -331,7 +344,10 @@ void svc_refresh( ){
 							}
 						}
 
-						snprintf(process->name, sizeof(process->name), "%s", cmd);
+						if(is_shell)
+							snprintf(process->name, sizeof(process->name), "sh: %s", cmd);
+						else
+							snprintf(process->name, sizeof(process->name), "%s", cmd);
 						process->state = state;
 						process->pid = pid;
 						process->rss = rss;
@@ -395,11 +411,12 @@ void svc_refresh( ){
 
 	// GPS
 	{
-		unsigned nr_gps_services = svc_gps_DRIVER + svc_gps_SUPL + svc_gps_CLOCKD;
+		unsigned nr_gps_services = svc_gps_DRIVER + svc_gps_SUPL + svc_gps_CLOCKD + svc_gps_GUARD;
 		unsigned nr_services = 1;
 
 		if(file_exists("/etc/init.d/supllistenerd")) nr_services++; // optional service (A-GPS)
 		if(file_exists("/etc/init.d/gpsclockd")) nr_services++; // optional service
+		if(file_exists("/etc/init.d/gpsdriver_guard")) nr_services++; // optional service
 		if(nr_gps_services == nr_services)
 			tmp_status = 2;
 		else if(nr_gps_services)
@@ -501,9 +518,9 @@ void svc_init_bluetooth( e_service_action action, unsigned with_ticks ){
 				usleep(500000); // sleep 500ms to let bluez service process request
 			}
 
-			if(svc_bluetooth_OBEX) system("/etc/init.d/obexsrv stop");
-			if(svc_bluetooth_BTCOND) system("/etc/init.d/btcond stop");
-			if(svc_bluetooth_HCI) system("/etc/init.d/bluez-utils stop");
+			if(svc_bluetooth_OBEX) system("/etc/init.d/obexsrv stop");		// K20
+			if(svc_bluetooth_BTCOND) system("/etc/init.d/btcond stop");		// K20
+			if(svc_bluetooth_HCI) system("/etc/init.d/bluez-utils stop");	// K74
 
 			sleep(1);
 			svc_refresh();
@@ -511,9 +528,9 @@ void svc_init_bluetooth( e_service_action action, unsigned with_ticks ){
 		break;
 	case SVC_START:
 		if(svc_bluetooth_status != 2){
-			if(!svc_bluetooth_HCI) system("/etc/init.d/bluez-utils start"); // sends a "bt set on" notification
-			if(!svc_bluetooth_BTCOND) system("/etc/init.d/btcond start");
-			if(!svc_bluetooth_OBEX) system("/etc/init.d/obexsrv start");
+			if(!svc_bluetooth_HCI) system("/etc/init.d/bluez-utils start");	// S56 - sends a "bt set on" notification
+			if(!svc_bluetooth_BTCOND) system("/etc/init.d/btcond start");	// S57
+			if(!svc_bluetooth_OBEX) system("/etc/init.d/obexsrv start");	// S70
 
 			// takes a few seconds to start, wait up to 9 seconds
 			int i;
@@ -538,19 +555,21 @@ void svc_init_gps( e_service_action action ){
 
 // TODO: toggle hardware OFF
 
-			if(svc_gps_SUPL) system("/etc/init.d/supllistenerd stop"); // optional service (A-GPS)
-			if(svc_gps_CLOCKD) system("/etc/init.d/gpsclockd stop"); // optional service
-			// libgpsbt doesn't use a process and therefore can't be stopped
-			if(svc_gps_DRIVER) system("/etc/init.d/gpsdriver stop");
+			if(svc_gps_GUARD) system("/etc/init.d/gpsdriver_guard stop");	// xxx - optional service
+			if(svc_gps_SUPL) system("/etc/init.d/supllistenerd stop");		// K20 - optional service (A-GPS)
+			if(svc_gps_CLOCKD) system("/etc/init.d/gpsclockd stop");		// xxx - optional service
+			// libgpsbt														// K20 - doesn't use a process and therefore can't be stopped
+			if(svc_gps_DRIVER) system("/etc/init.d/gpsdriver stop");		// K20
 			changed = 1;
 		}
 		break;
 	case SVC_START:
 		if(svc_gps_status != 2){
-			if(!svc_gps_DRIVER) system("/etc/init.d/gpsdriver start");
-			system("/etc/init.d/libgpsbt start");
-			if(!svc_gps_SUPL && file_exists("/etc/init.d/supllistenerd")) system("/etc/init.d/supllistenerd start"); // optional service (A-GPS)
-			if(!svc_gps_CLOCKD && file_exists("/etc/init.d/gpsclockd")) system("/etc/init.d/gpsclockd start"); // optional service
+			if(!svc_gps_DRIVER) system("/etc/init.d/gpsdriver start");														// S54
+			system("/etc/init.d/libgpsbt start");																			// S54
+			if(!svc_gps_SUPL && file_exists("/etc/init.d/supllistenerd")) system("/etc/init.d/supllistenerd start");		// S54 - optional service (A-GPS)
+			if(!svc_gps_CLOCKD && file_exists("/etc/init.d/gpsclockd")) system("/etc/init.d/gpsclockd start");				// S99 - optional service
+			if(!svc_gps_GUARD && file_exists("/etc/init.d/gpsdriver_guard")) system("/etc/init.d/gpsdriver_guard start");	// S99 - optional service
 			changed = 1;
 		}
 		break;
@@ -573,11 +592,13 @@ void svc_init_wifi( e_service_action action, unsigned with_ticks ){
 				usleep(500000); // sleep 500ms to let icd2 service process request
 			}
 
-			if(svc_wifi_NTPD) system("/etc/init.d/openntpd stop"); // optional service
-			if(svc_wifi_WLANCOND) system("/etc/init.d/wlancond stop");
-			if(svc_wifi_DNSMASQ) system("/etc/init.d/dnsmasq stop");
-			if(svc_wifi_CONNDLGS) system("/etc/osso-af-init/osso-connectivity-ui.sh stop");
-			if(svc_wifi_ICD) system("/etc/init.d/icd2 stop");
+			if(svc_wifi_NTPD) system("/etc/init.d/openntpd stop");								// K20 - optional service
+			if(svc_wifi_CONNDLGS) system("/etc/osso-af-init/osso-connectivity-ui.sh stop");		// K20
+			if(svc_wifi_ICD) system("/etc/init.d/icd2 stop");									// K15
+			if(svc_wifi_WLANCOND) system("/etc/init.d/wlancond stop");							// K20
+			// /etc/init.d/osso-ipv6 stop														// K20
+			// /etc/init.d/wide-dhcpv6-client													// K40
+			if(svc_wifi_DNSMASQ) system("/etc/init.d/dnsmasq stop");							// K85
 
 			sleep(1);
 			svc_refresh();
@@ -585,11 +606,13 @@ void svc_init_wifi( e_service_action action, unsigned with_ticks ){
 		break;
 	case SVC_START:
 		if(svc_wifi_status != 2){
-			if(!svc_wifi_ICD) system("/etc/init.d/icd2 start");
-			if(!svc_wifi_WLANCOND) system("/etc/init.d/wlancond start");
-			if(!svc_wifi_DNSMASQ) system("/etc/init.d/dnsmasq start");
-			if(!svc_wifi_CONNDLGS) system("/etc/osso-af-init/osso-connectivity-ui.sh start"); // will only start when launched as root, sudo doesn't work
-			if(!svc_wifi_NTPD && file_exists("/etc/init.d/openntpd")) system("/etc/init.d/openntpd start"); // optional service
+			if(!svc_wifi_DNSMASQ) system("/etc/init.d/dnsmasq start");										// S53
+			// /etc/init.d/osso-ipv6 start																	// S54
+			if(!svc_wifi_WLANCOND) system("/etc/init.d/wlancond start");									// S58
+			// /etc/init.d/wide-dhcpv6-client start															// S58
+			if(!svc_wifi_ICD) system("/etc/init.d/icd2 start");												// S59
+			if(!svc_wifi_CONNDLGS) system("/etc/osso-af-init/osso-connectivity-ui.sh start");				// S60 - will only start when launched as root, sudo doesn't work
+			if(!svc_wifi_NTPD && file_exists("/etc/init.d/openntpd")) system("/etc/init.d/openntpd start");	// S20 - optional service
 
 			// takes a few seconds to start, wait up to 9 seconds
 			int i;
@@ -611,21 +634,23 @@ void svc_init_audio( e_service_action action ){
 	switch(action){
 	case SVC_STOP:
 		if(svc_audio_status){
-			if(svc_audio_ENGINE) system("/etc/init.d/mediaplayer-daemon stop");
-			if(svc_audio_MULTIMEDIA) system("/etc/init.d/multimediad stop");
-			if(svc_audio_SERVER) system("/etc/osso-af-init/osso-media-server.sh stop");
-//			if(svc_audio_ESD) system("/etc/init.d/esd stop");								// won't stop, sound applet restarts it
-//			if(svc_audio_DSP) system("/etc/init.d/dsp-init stop");							// won't stop
+			// /etc/init.d/metalayer-crawler0 stop											// K01
+			if(svc_audio_ENGINE) system("/etc/init.d/mediaplayer-daemon stop");				// K01
+			if(svc_audio_SERVER) system("/etc/osso-af-init/osso-media-server.sh stop");		// K20
+//			if(svc_audio_ESD) system("/etc/init.d/esd stop");								// K26 - won't stop, sound applet restarts it
+			if(svc_audio_MULTIMEDIA) system("/etc/init.d/multimediad stop");				// K75
+//			if(svc_audio_DSP) system("/etc/init.d/dsp-init stop");							// K24 - won't stop
 			changed = 1;
 		}
 		break;
 	case SVC_START:
 		if(svc_audio_status != 2){
-			if(!svc_audio_DSP) system("/etc/init.d/dsp-init start");
-			if(!svc_audio_ESD) system("/etc/init.d/esd start");
-			if(!svc_audio_SERVER) system("/etc/osso-af-init/osso-media-server.sh start");	// will only start when launched as root, sudo doesn't work
-			if(!svc_audio_MULTIMEDIA) system("/etc/init.d/multimediad start");
-			if(!svc_audio_ENGINE) system("/etc/init.d/mediaplayer-daemon start");
+			if(!svc_audio_DSP) system("/etc/init.d/dsp-init start");						// S24
+			if(!svc_audio_MULTIMEDIA) system("/etc/init.d/multimediad start");				// S25
+			if(!svc_audio_ESD) system("/etc/init.d/esd start");								// S26
+			if(!svc_audio_SERVER) system("/etc/osso-af-init/osso-media-server.sh start");	// S60 will only start when launched as root, sudo doesn't work
+			if(!svc_audio_ENGINE) system("/etc/init.d/mediaplayer-daemon start");			// S99
+			// /etc/init.d/metalayer-crawler0 start											// S99
 			changed = 1;
 		}
 		break;
