@@ -177,16 +177,18 @@ void draw_battery_widget( unsigned force, int x, int y ){
 		x_draw_line(x+199, y, x+199, y+99);
 
 		// memory or swap usage
-		if(hw_swap.total && show_swap)
+		if(hw_swap.total && show_swap && !drawing_popup_window)
 			draw_mem_format("swap", hw_swap.free, hw_swap.total, cfg_swap_format, x, y);
 		else
 			draw_mem_format("memory", hw_memory.free, hw_memory.total, cfg_memory_format, x, y);
 
 		// cpu usage
-		snprintf(buffer, sizeof(buffer), "%d%% cpu", hw_cpu.usage);
-		draw_text(buffer, (hw_cpu.usage > 33 ? 20 : 18),
-			(hw_cpu.usage > 50 ? red_status_color : (hw_cpu.usage ? yellow_status_color : fg2_color)),
-			x+246, y+92, ALIGN_CENTER, ALIGN_BOTTOM, 0);
+			if(!drawing_popup_window){
+			snprintf(buffer, sizeof(buffer), "%d%% cpu", hw_cpu.usage);
+			draw_text(buffer, (hw_cpu.usage > 33 ? 20 : 18),
+				(hw_cpu.usage > 50 ? red_status_color : (hw_cpu.usage ? yellow_status_color : fg2_color)),
+				x+246, y+92, ALIGN_CENTER, ALIGN_BOTTOM, 0);
+		}
 
 		if(!drawing_popup_window) draw_tap_markers(x+201, y, 99, 1, hw_swap.total); // short tap only (long tap if swap is enabled)
 
