@@ -1009,6 +1009,8 @@ void draw_popup_window( ){
 	int w, h;
 	if(cfg_popup_fullscreen){ w = window.width; h = window.height; } else { w = POPUP_WIDTH; h = POPUP_HEIGHT; }
 
+	hw_refresh_popup();
+
 	drawing_popup_window = 1;
 	if(cfg_popup_fullscreen){
 		// background
@@ -1047,6 +1049,12 @@ void window_open_popup( ){
 	if(popup_window_open || !cfg_popup_duration || use_minimal_ui || current_dialog_draw == draw_flashlight || current_dialog_draw == draw_fullsreen_clock)
 		return;
 
+	// don't show if ASUI is mapped unless secured
+	if(cfg_popup_noasui && window.is_mapped && !hw_device_locked) return;
+
+	// don't open another popup until cooldown timer expires
+	if(current_time - popup_window_close_time < cfg_popup_cooldown) return;
+
 	debug_write("window_open_popup()");
 
 	// open display
